<template>
  <div class="custom-crud-page">
    <el-bus-crud ref="crud" v-bind="crudConfig"></el-bus-crud>
  </div>
</template>

<script>
const passwordPattern =
  /^(?:(?=\S*\d)(?=\S*[A-Z])(?=\S*[a-z])(?=\S*[-_!@#$%^&*? ]))\S{8,20}$/
const passwordPatternMessage =
  '请输入正确的密码(8-20位，包括至少1个大写字母，1个小写字母，1个数字，1个特殊字符)'
export default {
  data() {
    return {
      crudConfig: {
        url: 'flower/api/user/list',
        canEdit: (row) => row.isSys !== 'Y',
        canDelete: (row) => row.isSys !== 'Y',
        dialogNeedRequest: true,
        operationAttrs: {
          width: '200px',
          fixed: 'right',
        },
        beforeOpen: (row, isNew) => {
          if (!isNew) {
            if (!row.employeeDTO) {
              row.employeeDTO = {}
            }
          }
        },
        extraButtons: [
          {
            text: '重置密码',
            show: (row) => row.isSys !== 'Y',
            atClick: (row) => {
              this.$prompt('请输入新密码', '提示', {
                confirmButtonText: '确定',
                cancelButtonText: '取消',
                inputPattern: passwordPattern,
                inputErrorMessage: passwordPatternMessage,
              })
                .then(async ({ value }) => {
                  const { code } = await this.$elBusHttp.request(
                    'flower/api/user/reset/password',
                    {
                      method: 'post',
                      data: {
                        userId: row.id,
                        password: value,
                      },
                    }
                  )
                  if (code === 0) {
                    this.$message.success('重置密码成功')
                  }
                })
                .catch(() => {})
            },
          },
        ],
        columns: [
          { label: '序号', type: 'index', width: 60 },
          { label: '姓名', prop: 'nickName', minWidth: 120 },
          { label: '性别', prop: 'genderStr', minWidth: 60 },
          { label: '职位', prop: 'postName', minWidth: 120 },
          { label: '工作内容', prop: 'workContent', minWidth: 180 },
          { label: '手机号', prop: 'tel', minWidth: 120 },
          { label: '角色', prop: 'roleDesc', minWidth: 100 },
          {
            label: '状态',
            prop: 'statusStr',
            formatter: (row) => {
              return (
                <el-switch
                  value={row.status === 'A'}
                  onChange={this.changeStatus.bind(this, row)}
                >
                  正常
                </el-switch>
              )
            },
            minWidth: 100,
          },
          { label: '创建时间', prop: 'createdDate', minWidth: 180 },
          { label: '创建者', prop: 'createdName', minWidth: 120 },
        ],
        searchForm: [
          {
            type: 'row',
            span: 6,
            items: [
              {
                label: '用户名',
                id: 'loginName',
                type: 'input',
                el: { placeholder: '用户名/姓名/手机号' },
              },
              {
                label: '状态',
                id: 'status',
                type: 'bus-select-dict',
                el: {
                  clearable: true,
                  code: 'USER_STATUS',
                  style: 'width:100%',
                  placeholder: '全部',
                },
              },
            ],
          },
        ],
        form: [
          {
            label: '手机号：',
            id: 'tel',
            type: 'input',
            rules: [
              {
                pattern: this.$elBusUtil.REG.MOBILEPHONE,
                message: '请输入合法的手机号',
                trigger: 'blur',
              },
            ],
          },
          {
            label: '用户名：',
            id: 'loginName',
            type: 'input',
            rules: { required: true, message: '请输入用户名', trigger: 'blur' },
          },
          {
            label: '姓名：',
            id: 'nickName',
            type: 'input',
            rules: { required: true, message: '请输入姓名', trigger: 'blur' },
          },
          {
            type: 'group',
            id: 'employeeDTO',
            items: [
              {
                label: '性别：',
                id: 'gender',
                type: 'bus-select-dict',
                el: { code: 'gender', clearable: true },
                str: true,
              },
              {
                label: '出生年月日：',
                id: 'birthday',
                type: 'date-picker',
                el: {
                  valueFormat: 'yyyy-MM-dd',
                  placeholder: '请选择',
                },
              },
              {
                label: '身份证：',
                id: 'idCard',
                type: 'input',
              },
              {
                label: '职位：',
                id: 'postName',
                type: 'input',
              },
              {
                label: '工作内容：',
                id: 'workContent',
                type: 'input',
              },
              {
                label: '入职时间：',
                id: 'inDate',
                type: 'date-picker',
                el: {
                  valueFormat: 'yyyy-MM-dd',
                  placeholder: '请选择',
                },
              },
              {
                label: '薪资待遇：',
                id: 'salary',
                type: 'input-number',
                el: {
                  precision: 0,
                  min: 0,
                },
                unit: '元/月',
              },
            ],
          },
          {
            label: '密码：',
            id: 'password',
            type: 'input',
            rules: (row, mode) => [
              {
                required: mode === 'new',
                message: '请输入密码',
                trigger: 'blur',
              },
              {
                pattern: passwordPattern,
                message: passwordPatternMessage,
                trigger: 'blur',
              },
            ],
            hidden: (row, _, mode) => mode !== 'new',
          },
          {
            label: '确认密码：',
            id: 'confirmPassword',
            type: 'input',
            rules: (row, mode) => [
              {
                required: mode === 'new',
                message: '请输入确认密码',
                trigger: 'blur',
              },
              {
                validator: (rule, value, callback) => {
                  if (row.password) {
                    if (value === '' || !value) {
                      callback(new Error('请重复输入密码!'))
                    } else if (row.password !== value) {
                      callback(new Error('重复输入密码不一致!'))
                    } else {
                      callback()
                    }
                  } else {
                    callback()
                  }
                },
                trigger: 'blur',
              },
            ],
            hidden: (row, _, mode) => mode !== 'new',
          },
          {
            label: '角色：',
            id: 'roleIds',
            str: true,
            strKey: 'roleDesc',
            type: 'bus-select',
            el: {
              interfaceUri: 'flower/api/role/list',
              immediate: true,
              multiple: true,
              props: {
                label: 'roleName',
                value: 'id',
                dataPath: 'records',
              },
              extraQuery: {
                size: 2000,
              },
              style: 'width:100%',
            },
            rules: { required: true, message: '请选择角色' },
          },
          {
            label: '状态：',
            id: 'status',
            str: true,
            type: 'bus-select-dict',
            el: {
              code: 'COMMON_STATUS',
              placeholder: '请选择状态',
              style: 'width:100%',
            },
            rules: { required: true, message: '请选择状态' },
          },
        ],
      },
    }
  },
  head() {
    return {
      title: '员工管理',
    }
  },
  methods: {
    async changeStatus(row, e) {
      const url = e
        ? `flower/api/user/enable/${row.id}`
        : `flower/api/user/disable/${row.id}`
      const action = e ? '启用' : '禁用'
      const { code } = await this.$elBusHttp.request(url, { method: 'post' })
      if (code === 0) {
        this.$message.success(`${action}成功`)
        this.$refs.crud.getList()
      }
    },
  },
}
</script>
